'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('@emotion/react');
var React = require('react');
var styled = require('@emotion/styled');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var styled__default = /*#__PURE__*/_interopDefaultLegacy(styled);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __makeTemplateObject(cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
}

var ThemeProvider = function (_a) {
    var children = _a.children, props = __rest(_a, ["children"]);
    return React__default['default'].createElement(react.ThemeProvider, __assign({}, props), children);
};
var lightTheme = {
    colors: {
        primary: '#3562ff',
        primaryVariant: '',
        secondary: '',
        secondaryVariant: '',
        text: '#1a1a1a',
        info: '',
        background: '',
        error: '',
    },
    font: {
        primary: 'Noto Sans KR',
        secondary: '',
    },
};
var darkTheme = {
    colors: {
        primary: '',
        primaryVariant: '',
        secondary: '',
        secondaryVariant: '',
        text: '',
        info: '',
        background: '',
        error: '',
    },
    font: {
        primary: 'Noto Sans KR',
        secondary: '',
    },
};
var getTheme = function (type) {
    return type === 'light' ? lightTheme : darkTheme;
};

var MOBILE = 2;
var DESKTOP = MOBILE * 1.25;
var Text = function (_a) {
    var h1 = _a.h1, h2 = _a.h2, h3 = _a.h3, p = _a.p, className = _a.className, children = _a.children, props = __rest(_a, ["h1", "h2", "h3", "p", "className", "children"]);
    var type = React.useMemo(function () {
        if (h1)
            return 'h1';
        if (h2)
            return 'h2';
        if (h3)
            return 'h3';
        return 'p';
    }, [h1, h2, h3, p]);
    switch (type) {
        case 'h1':
            return (React__default['default'].createElement(StyledTextTitle1, __assign({ className: className }, props), children));
        case 'h2':
            return (React__default['default'].createElement(StyledTextTitle2, __assign({ className: className }, props), children));
        case 'h3':
            return (React__default['default'].createElement(StyledTextTitle3, __assign({ className: className }, props), children));
        default:
            return (React__default['default'].createElement(StyledTextNormal, __assign({ className: className }, props), children));
    }
};
var getStripUnit = function (value) {
    return value * (value * 0 + 1);
};
var getFontSize = function (_a) {
    var _b = _a.minWidth, minWidth = _b === void 0 ? 768 : _b, _c = _a.maxWidth, maxWidth = _c === void 0 ? 1080 : _c, _d = _a.minFont, minFont = _d === void 0 ? MOBILE * 10 : _d, _e = _a.maxFont, maxFont = _e === void 0 ? DESKTOP * 10 : _e;
    return "& {\n    font-size: " + minFont + "px;\n    @media screen and (min-width: " + minWidth + "px) {\n      font-size: calc(" + minFont + "px + " + getStripUnit(maxFont - minFont) + " * ((100vw - " + minWidth + "px) / " + getStripUnit(maxWidth - minWidth) + "));\n    }\n    @media screen and (min-width: " + maxWidth + "px) {\n      font-size: " + maxFont + "px;\n    }\n  }";
};
var StyledTextTitle1 = styled__default['default'].h1(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  font-weight: 900;\n  font-family: ", ";\n  color: ", ";\n  line-height: 1.4;\n\n  ", "\n"], ["\n  font-weight: 900;\n  font-family: ", ";\n  color: ", ";\n  line-height: 1.4;\n\n  ", "\n"])), function (props) { return props.theme.font.primary; }, function (props) { return props.theme.colors.text; }, function (props) {
    var minWidth = props.minWidth, maxWidth = props.maxWidth, minFont = props.minFont, maxFont = props.maxFont;
    return getFontSize({
        minWidth: minWidth || 400,
        maxWidth: maxWidth || 1160,
        minFont: minFont || MOBILE * 24,
        maxFont: maxFont || DESKTOP * 24,
    });
});
var StyledTextTitle2 = styled__default['default'].h2(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  font-weight: 700;\n  font-family: ", ";\n  color: ", ";\n  line-height: 1.4;\n\n  ", "\n"], ["\n  font-weight: 700;\n  font-family: ", ";\n  color: ", ";\n  line-height: 1.4;\n\n  ", "\n"])), function (props) { return props.theme.font.primary; }, function (props) { return props.theme.colors.text; }, function (props) {
    var minWidth = props.minWidth, maxWidth = props.maxWidth, minFont = props.minFont, maxFont = props.maxFont;
    return getFontSize({
        minWidth: minWidth || 400,
        maxWidth: maxWidth || 1160,
        minFont: minFont || MOBILE * 20,
        maxFont: maxFont || DESKTOP * 20,
    });
});
var StyledTextTitle3 = styled__default['default'].h3(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  font-weight: 700;\n  font-family: ", ";\n  color: ", ";\n  line-height: 1.4;\n\n  ", "\n"], ["\n  font-weight: 700;\n  font-family: ", ";\n  color: ", ";\n  line-height: 1.4;\n\n  ", "\n"])), function (props) { return props.theme.font.primary; }, function (props) { return props.theme.colors.text; }, function (props) {
    var minWidth = props.minWidth, maxWidth = props.maxWidth, minFont = props.minFont, maxFont = props.maxFont;
    return getFontSize({
        minWidth: minWidth || 400,
        maxWidth: maxWidth || 1160,
        minFont: minFont || MOBILE * 16,
        maxFont: maxFont || DESKTOP * 16,
    });
});
var StyledTextNormal = styled__default['default'].p(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  font-weight: 300;\n  font-family: ", ";\n  color: ", ";\n  line-height: 1.2;\n\n  ", "\n"], ["\n  font-weight: 300;\n  font-family: ", ";\n  color: ", ";\n  line-height: 1.2;\n\n  ", "\n"])), function (props) { return props.theme.font.primary; }, function (props) { return props.theme.colors.text; }, function (props) {
    var minWidth = props.minWidth, maxWidth = props.maxWidth, minFont = props.minFont, maxFont = props.maxFont;
    return getFontSize({
        minWidth: minWidth || 400,
        maxWidth: maxWidth || 1160,
        minFont: minFont || MOBILE * 10,
        maxFont: maxFont || DESKTOP * 10,
    });
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;

exports.Text = Text;
exports.ThemeProvider = ThemeProvider;
exports.darkTheme = darkTheme;
exports.getTheme = getTheme;
exports.lightTheme = lightTheme;
//# sourceMappingURL=index.js.map
